# Unification Mainnet Helpers

Miscellaneous tools to help support the provisioning and maintance of EV can be found here.

## Revert

To revert all data, fetch the latest binary, and uses the lastest published 
genesis.

```
python -m mainchain.upgrade revert
```


## Network upgrades

The module `mainchain.upgrade` supports network upgrades

```
python -m mainchain.upgrade genesis 700000
```

where 700000 is the block height.
